string_between

Using string_between
====================

.. code-block:: python

    import string_between
    
    # example usage
    
    > b'result'

Changelog
=========

0.0.1: initial release (2021-09-07)

